@@ -42,6 +42,8 @@ public class CDFDump extends JFrame
     int abcX = 0;
 /** "Run it Batch" checkbox. */
     JCheckBox bac = new JCheckBox("Run it Batch");
+/** "Noheader" checkbox. */
+    JCheckBox qec = new JCheckBox("Noheader");
 
 /** A label of "Dump:" for the radio button zmode. */
     JLabel DUMP = new JLabel("Dump:  ");
@@ -101,6 +103,7 @@ public class CDFDump extends JFrame
 /** The file separator. */
     String separator = System.getProperty("file.separator");
     String struf = "-format ";
+    String strqe = " ";
     String strdp = "all ";
     String cdfspec = " ";
     String filespec = "";
@@ -295,12 +298,13 @@ public class CDFDump extends JFrame
         // Panel 2
 
         makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, ufc, 0, 1, 1, 1, 0.0, 0.0);
+	makeJButton(panel2n, abc, 0, 1, 1, 1, 0.0, 0.0);
         makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 1, 1, 1, 0.0, 0.0);
-	makeJButton(panel2n, abc, 2, 1, 1, 1, 0.0, 0.0);
-	makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 1, 1, 1, 0.0, 0.0);
-//        makeJButton(panel2n, bac, 4, 1, 1, 1, 0.0, 0.0);
-        makeJButton(panel2n, tpanel1, 0, 2, 1, 1, 0.0, 0.0);
+        makeJButton(panel2n, qec, 2, 1, 1, 1, 0.0, 0.0);
+//        makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 1, 1, 1, 0.0, 0.0);
+	makeJButton(panel2n, ufc, 0, 2, 1, 1, 0.0, 0.0);
+	makeJButton(panel2n, Box.createRigidArea(hpad40), 1, 2, 1, 1, 0.0, 0.0);
+        makeJButton(panel2n, tpanel1, 2, 2, 1, 1, 0.0, 0.0);
         makeJButton(panel2n, Box.createRigidArea(vpad5), 0, 3, 1, 1, 0.0, 0.0);
         makeJButton(panel2s, Box.createRigidArea(vpad5), 0, 0, 1, 1, 0.0, 0.0);
         makeJButton(panel2s, VARS, 0, 1, 1, 1, 1.0, 1.0);
@@ -313,6 +317,8 @@ public class CDFDump extends JFrame
 	ufc.setToolTipText("Select to use FORMAT attribute when displaying variable data");
 	abc.addItemListener(this);
         abc.setToolTipText("Display the current version");
+        qec.addItemListener(this);
+        qec.setToolTipText("Remove the 1-line header \"Dumping cdf from ...\" from the dump report");
         bac.addItemListener(this);
         bac.setToolTipText("Select to set up and run the dump by a batch job");
         vars.addActionListener(this);
@@ -458,9 +464,20 @@ public class CDFDump extends JFrame
 		if (cdfspec.startsWith("'")) cdfDelimiter = " ";
 		else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
 		else cdfDelimiter = "\"";
+		
+		if (ufc.isSelected())
+		  struf = "-format ";
+		else
+		  struf = "-noformat ";
 
-		commandX = command + struf + "-dump " + strdp + " " + xxx + yyy +
-                           " " + cdfDelimiter + cdfspec + cdfDelimiter;
+		if (qec.isSelected())
+		  strqe = "-noheader ";
+		else
+		  strqe = " ";
+
+		commandX = command + struf + strqe + "-dump " + strdp + " " + 
+                           xxx + yyy + " " + cdfDelimiter + cdfspec + 
+                           cdfDelimiter;
 
                 String OS = System.getProperty("os.name").toLowerCase();
                 if (OS.indexOf("windows") != -1) {
@@ -648,6 +665,8 @@ public class CDFDump extends JFrame
                 process = runtime.exec(command);
               else
                 process = runtime.exec(command[0]);
+
+              info.setText("");
 /*
               if (hlp == 0 && abcX == 0) {
                 if (!filespec.equals("") && !filespec.trim().equals("")) {                 
