@@ -50,6 +50,7 @@ public class CDFInquire extends JFrame
 /** command string. */
     String command = "cdfinquire ";
     String commandX;
+    String[] cmds = new String[3];
 
 /** The file separator. */
     String separator = System.getProperty("file.separator");
@@ -249,15 +250,33 @@ public class CDFInquire extends JFrame
               } else {System.exit(1);}
 	} else if (obj == entrb) { // for "Enter" button
 		commandX = command + " -id " + "-nopage ";
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 	} else { // for "Help" button
 		hlp = 1;
                 commandX = command + " -java"; 
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 	}
     }
 
@@ -269,9 +288,18 @@ public class CDFInquire extends JFrame
 	  if (abc.isSelected()) {
 		abx = 1;
 		commandX = command + " -about";
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
                 abc.setSelected(false);
 		abx = 0;
 	  }
@@ -317,15 +345,13 @@ public class CDFInquire extends JFrame
 /** Execute a command as a separate process for the user selection and returns 
     the results in the text area.
  */ 
-    // private void runit(String[] command) {
-    private void runit(String command) {
+    private void runit(String[] command) {
+    // private void runit(String command) {
         try {
-           if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-              command = command.replace('-', '/');
-
-		// if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-		//   command[2] = command[2].replace('-', '/');
-                process = runtime.exec(command);
+		if (command[1] != null) 
+                  process = runtime.exec(command);
+                else
+                  process = runtime.exec(command[0]);
                 if (hlp == 0 && abx == 0) { // skip if just for help info
                         info.setText("Program is running...\n");
                 }
