@@ -118,6 +118,7 @@ public class SkeletonCDF extends JFrame
 /** The command string. */
     String command = "skeletoncdf ";
     String commandX;
+    String[] cmds = new String[3];
 
 /** Environment variable for the current directory. */
     String currentdir = System.getProperty("user.dir");
@@ -360,7 +361,7 @@ public class SkeletonCDF extends JFrame
         makeJButton(panel2n, Box.createRigidArea(hpad40), 3, 2, 1, 1, 1.0, 1.0);
 	makeJButton(panel2n, tpanel1, 4, 2, 1, 1, 1.0, 1.0);
         makeJButton(panel2n, abc, 0, 3, 1, 1, 1.0, 1.0);
-        makeJButton(panel2n, bac, 2, 3, 1, 1, 1.0, 1.0);
+//        makeJButton(panel2n, bac, 2, 3, 1, 1, 1.0, 1.0);
 	makeJButton(panel2n, Box.createRigidArea(vpad10), 0, 4, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, CASS, 0, 0, 1, 1, 1.0, 1.0);
         makeJButton(panel2s, cachesizes, 1, 0, 2, 1, 1.0, 1.0);
@@ -480,11 +481,22 @@ public class SkeletonCDF extends JFrame
 	} else if (obj == helpb || obj == menuHelpHelp) { // for "Help" 
 		commandX = command + "-java";
 		hlp = 1;
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+		iba = 0;
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 		hlp = 0;
 	} else if (obj == entrb) { // for "Enter" button
+		iba = 1;
                 cdfspec = cdf.getText();
                 skltspec = sklt.getText();
                 if (skltspec.equals("") || skltspec.trim().equals("")) {
@@ -516,31 +528,41 @@ public class SkeletonCDF extends JFrame
 		   else Caches = "-cache " + caches + " ";
 		}
 
-		if (cdfspec.trim().equals("")) cdfspec = " ";
+		if (cdfspec.equals("") || cdfspec.trim().equals("")) cdfspec = " ";
 		else {
                   if (cdfspec.startsWith("'")) cdfDelimiter = " ";
                   else if (cdfspec.startsWith("\"")) cdfDelimiter = " ";
-                  else cdfDelimiter = "'";
-		  // cdfspec = "-cdf " + cdfDelimiter + cdfspec + cdfDelimiter + " ";
-		  cdfspec = "-cdf " + " " + cdfspec + " ";
+                  else cdfDelimiter = "\"";
+		  cdfspec = "-cdf " + cdfDelimiter + cdfspec + cdfDelimiter + " ";
+		  // cdfspec = "-cdf " + " " + cdfspec + " ";
 		}
 
                 if (skltspec.startsWith("'")) sktDelimiter = " ";
                 else if (skltspec.startsWith("\"")) sktDelimiter = " ";
-                else sktDelimiter = "'";
+                else sktDelimiter = "\"";
 
-		/************
                 commandX = command  + strzz + struf + strlp +
 			   strds + strde + report + Zmode + 
 			   Caches + cdfspec + sktDelimiter + skltspec +
 			   sktDelimiter;
-                *************/
+                /*************
 		commandX = command  + strzz + struf + strlp +
 			   strds + strde + report + Zmode + 
 			   Caches + cdfspec + " " + skltspec;
-                // String[] cmds = {"/bin/sh", "-c", commandX};
-                // runit(cmds);
-                runit(commandX);
+		*************/
+                String OS = System.getProperty("os.name").toLowerCase();
+                if (OS.indexOf("windows") != -1) {
+                    cmds[0] = commandX;
+                } else if (OS.indexOf("vms") != -1) {
+                    commandX = commandX.replace('-', '/');
+                    cmds[0] = commandX;
+                } else {
+                    cmds[0] = "/bin/sh";
+                    cmds[1] = "-c";
+                    cmds[2] = commandX;
+                }
+                runit(cmds);
+                // runit(commandX);
 	} else if (obj == cdf) { // "CDF" text field
 		cdfspec = cdf.getText();
 	} else if (obj == sklt) { // "Skeleton" text field
@@ -615,10 +637,20 @@ public class SkeletonCDF extends JFrame
 	} else if (obj == abc) { // "About" checkbox
                 if (abc.isSelected()) {
 		  abx = 1;
+		  iba = 0;
 		  commandX = command + " -about";
-                  // String[] cmds = {"/bin/sh", "-c", commandX};
-                  // runit(cmds);
-                  runit(commandX);
+                  String OS = System.getProperty("os.name").toLowerCase();
+                  if (OS.indexOf("windows") != -1) {
+                      cmds[0] = commandX;
+                  } else if (OS.indexOf("vms") != -1) {
+                      cmds[0] = commandX;
+                  } else {
+                      cmds[0] = "/bin/sh";
+                      cmds[1] = "-c";
+                      cmds[2] = commandX;
+                  }
+                  runit(cmds);
+                  // runit(commandX);
                   abc.setSelected(false);
 		  abx = 0;
 		}
@@ -747,15 +779,14 @@ public class SkeletonCDF extends JFrame
 /** Execute a command as a separate process for the user selection and returns
     the results in the text area.
  */
-    // public void runit(String[] command) {
-    public void runit(String command) {
+    public void runit(String[] command) {
+    // public void runit(String command) {
 	try {
-		// if (System.getProperty("os.name").equalsIgnoreCase("VMS"))
-		//    command[2] = command[2].replace('-', '/');
-           if (System.getProperty("os.name").toLowerCase().indexOf("vms") != -1)
-              command = command.replace('-', '/');
-
-                process = runtime.exec(command);
+                if (command[1] != null)
+                  process = runtime.exec(command);
+                else
+                  process = runtime.exec(command[0]);
+/*
                 if (iba == 1 && hlp == 0) { // can't be batch if just for help
                         info.setText("Program is submitted...\n\n");
                         String myString;
@@ -776,45 +807,37 @@ public class SkeletonCDF extends JFrame
                         info.setText("");
                         info.append("Program is running...\n");
                   }
-                  Dimension dialogSize = dialog.getSize();
+*/
+                Dimension dialogSize = dialog.getSize();
                   ((JComponent)(dialog.getContentPane())).paintImmediately(
                                                 0, 0, dialogSize.width, dialogSize.height);
-                  BufferedReader inStream = new BufferedReader(new       
+                BufferedReader inStream = new BufferedReader(new       
                                   InputStreamReader(process.getInputStream()), 8192);
-		  boolean first = true; 
-                  String line = null;
-                  if (hlp == 1 || abx == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
-		      lpcX == 1 || dscX == 1) {
-		    while ((line = inStream.readLine()) != null) {
-		      if (first) {
+		boolean first = true; 
+                String line = null;
+                if (hlp == 1 || abx == 1 || ricX == 1 || rwcX == 1 || recX == 1 ||
+		    lpcX == 1 || dscX == 1) {
+		  while ((line = inStream.readLine()) != null) {
+		    if (first) {
 			info.setText("");
 			first = false;
-		      }
-                      info.append(line+"\n");
 		    }
+                    info.append(line+"\n");
 		  }
-                  process.waitFor();
-		  info.setCaretPosition(0);
-		  if (process.exitValue() == 1) Toolkit.getDefaultToolkit().beep();
-                  else {
-		    if (hlp == 0 && abx == 0) {
-                        String myString;
-			String extension, osname;
-                        info.append("Done!\n\n");
-			osname = System.getProperty("os.name");
-			extension = ".CDF";
-			if (osname.indexOf("UNIX") != -1) extension = ".cdf";
-			if (osname.indexOf("unix") != -1) extension = ".cdf";
-                        if (!cdf.getText().equals("")) {
-                          myString = cdf.getText().trim() + extension;
-                          info.append("A CDF: "+myString+"  is created.\n");
-                        } else {
-                          info.append("A CDF, with a name provided in the skeleton table, ");
-                          info.append("is created.\n");
-                        }
-		    }
+		}
+                process.waitFor();
+		info.setCaretPosition(0);
+		if (process.exitValue() == 1) 
+		  Toolkit.getDefaultToolkit().beep();
+                else {
+		  if (iba == 1) {
+			if (info.getText().toLowerCase().indexOf("error") == -1)
+
+                          info.append("Done!\n\n");
+			else
+                          info.append("ERROR: CDF file is not created or invalid.\n");
                   }
-		} 
+		}
 	} catch (Exception e) {
                 info.setText("error executing: "+e);
                 Toolkit.getDefaultToolkit().beep();
